# coding: utf-8
import json

import requests
from django.conf import settings


URL = 'https://yournotifier.com/api/v1/message/'


def send_notify(channel_name, text):
    headers = {'Authorization': 'Key {}'.format(settings.NOTIFIER_APIKEY)}
    res = requests.post(URL, headers=headers, data={'name': channel_name, 'text': text})
    return res.json()



from setuptools import setup

with open('README.rst', 'r') as f:
    long_description = f.read()

setup(
    name='django-yournotifier',
    version='1.0.1',
    author='Ivan Lukyanets',
    author_email='lukyanets.ivan@gmail.com',
    url='https://github.com/1vank1n/django-yournotifier',
    packages=[
        'yournotifier',
    ],
    include_package_data=True,
    license='MIT',
    description='A simple integration for use yournotifier.com',
    keywords='django yournotifier',
    long_description=long_description,
    install_requires=[
        'requests==2.19.1',
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.6',
    ],
)
